| Title: | Extracting purely text based information from supplement code |
|---|---|
| Description: | Extracting purely text based information from supplement code |
| Authors: | Sebastian Kranz (Ulm University) |
| Maintainer: | Sebastian Kranz <[email protected]> |
| License: | GPL >= 3.0 |
| Version: | 0.1 |
| Built: | 2026-05-26 07:38:34 UTC |
| Source: | https://github.com/repboxr/repboxCodeText |